import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.util.Calendar;
import java.util.Vector;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.List;
import javax.microedition.rms.RecordStore;

import peer2me.framework.Framework;
import peer2me.framework.FrameworkSubscriber;
import peer2me.message.Message;
import peer2me.network.bluetooth.Bluetooth;
import peer2me.node.Node;



public class Communicator implements FrameworkSubscriber, CommandListener{
    public Framework framework; // peer2me variable, must be used....    
	List nodeList;
	Vector nodesFound;
	boolean addShowNodes=false;
	public Node currentlySelectedNode =null;
	private Alert newmsgAlert;
    VMSMidlet midlet;    
    private Command okCommand = new Command("OK",Command.OK,10);
	private Command backCommand = new Command("Back",Command.BACK, 0);
	
    /**
	 * constructor which initializes the peer2me framework
	 */
    public Communicator(VMSMidlet vmsmid){
    	this.midlet = vmsmid;
    	//initialize framework
        framework = Framework.getInstance("MyGroup","VMS",new Bluetooth(),true,this);
        framework.setframeworkSubscriber(this);
        framework.initialize();
        
        nodeList = new List("Nodes", List.IMPLICIT);
        nodesFound = new Vector();
        nodeList.setCommandListener(this);
        nodeList.addCommand(backCommand);        
    }
    
        /**
	 * This method is called whenever a new {@link peer2me.node.Node} is discovered
	 * @param node the node which is discovered
	 */
	public void nodeDiscovered(Node node){
        nodesFound.addElement(node);
    }
	
	/**
	 * This is called whenever a {@link peer2me.node.Node} is lost or abscent 
	 * @param node the node that is lost or abscent
	 */
	public void nodeLost(Node node){
        nodesFound.removeElement(node);
    }
	
	/**
	 * This method is called whenever a {@link peer2me.message.Message} is received
	 * @param message the message that is received
	 */
	public void messageReceived(Message message){
	
		String from = message.getSender().toString();
		byte[] voiceMsg = (byte[])message.getMessagePart("Mes").getObjectBytes();
		// store recieved message in inbox
		saveFile(voiceMsg,from);
		
		newmsgAlert = new Alert("New Voice Message", "new voice message recieved from " + message.getSender().toString()+ "on " + Calendar.DATE,null,AlertType.INFO );
		newmsgAlert.setTimeout(Alert.FOREVER);
		midlet.display.setCurrent(newmsgAlert);		
    }
	
	/**
	 * This method is called for every part of a whole {@link peer2me.message.Message}
	 * that is received. Is well suited for display progressbars in the GUI etc.
	 * @param messageID the id of the message the part belongs to
	 * @param part the current part received
	 * @param total the total of parts to be received
	 */
	public void messagePartReceived(String messageID, int part, int total){
		
	}
	
	/**
	 * This method is called whenever a search for devices and services is finished.
	 *
	 */
	public void searchCompleted(){
		midlet.display.setCurrent(showNodes());
    }   
	/**
	 * returns a List of nodes known by the framework
	 */
	public List showNodes(){
		nodeList.deleteAll();
		Node[] nodes = framework.getAllNodes();
		
		for(int i= 0; i< nodes.length; i++)
		{	if(nodes[i].getAddress()!= framework.getLocalNode().getAddress())
			{	
				nodeList.append(nodes[i].toString(),null);
			}				
		}
		if(nodeList.size()==0){       	
			nodeList.append("No peers found",null);
			nodeList.removeCommand(okCommand);
		}else {
			nodeList.addCommand(okCommand);
		}
		return nodeList;
	}

	public void commandAction(Command c, Displayable arg1) {
		if (c== okCommand){
			currentlySelectedNode = (Node)nodesFound.elementAt(nodeList.getSelectedIndex());
			midlet.newVms.recipient.setString(currentlySelectedNode.getNodename());
			midlet.display.setCurrent(midlet.newVms);			
		}
		if (c== backCommand){			
			midlet.display.setCurrent(midlet.newVms);			
		}		
	}
	
	//code for storing sent message in outbox
	private void saveFile(byte[] recievedMsg, String from){
//**************open/create record store****************************************
	                try{
	                	midlet.inboxStore =RecordStore.openRecordStore("VMSinbox",true);
	                 
	                }catch(Exception err){
//	                    Display alert if an error occurs.......
	        			Alert errorAlert = new Alert("","Error opening inbox (Communicator) " + err.getMessage(),null,AlertType.ERROR);
	        			errorAlert.setTimeout(Alert.FOREVER);	        			
	        			midlet.display.setCurrent(errorAlert);
	                }

//	**************write data to record store***************************************
	                try{
	                    // data to store............
	                    byte[] outputRecord = recievedMsg;
	                    String nick = from;	                    
	                    ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
	                    DataOutputStream outputDataStream = new DataOutputStream(outputStream);	                    
	                    outputDataStream.writeUTF(nick);	                    
	                    outputDataStream.write(outputRecord);	                    
	                    outputDataStream.flush();
	                    outputRecord= outputStream.toByteArray();	                   
	                    midlet.inboxStore.addRecord(outputRecord,0,outputRecord.length);	                    
	                    // release resources
	                    outputStream.close();
	                    outputDataStream.close();
	                    
	                }catch(Exception err){
	               
//	                    Display alert if an error occurs.......
	        			Alert errorAlert = new Alert("","Error adding record to inbox (Communicator) " + err.getMessage(),null,AlertType.ERROR);
	        			errorAlert.setTimeout(Alert.FOREVER);	        			
	        			midlet.display.setCurrent(errorAlert);
	                }
	                
//	****************close record store, release resources**************************
	                try{
	                	midlet.inboxStore.closeRecordStore();
	                    
	                }catch(Exception err){
	                	
//	                    Display alert if an error occurs.......
	        			Alert errorAlert = new Alert("","Error closing inbox (Communicator) " + err.getMessage(),null,AlertType.ERROR);
	        			errorAlert.setTimeout(Alert.FOREVER);	        			
	        			midlet.display.setCurrent(errorAlert);
	                }	                
	                // update outboxView
	                midlet.inbox.update();
	        }

}
   
