import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.AlertType;
import javax.microedition.media.*;
import javax.microedition.media.control.RecordControl;
import javax.microedition.media.control.VolumeControl;

public class PlayerRecorder implements PlayerListener{
	
    public Player recorder=null;
    public Player player=null;
    public byte[] recordedSoundArray = null;
    NewVmsView myView; // reference to view to change UI components
    RecordControl rc;
    VolumeControl vc;
    
    ByteArrayOutputStream output;
    public boolean recPaused;
    public boolean recordingStopped; // flag to check stop on recordto avoid calling it twice
    public int MAX_LIMIT= 170000; // max limit for recording
    private PlayerListener myListener;
    
    public PlayerRecorder(NewVmsView nvms) {
        myView = nvms;
        recPaused =false;
        myListener = this;
    } 
    
    public void record(){   	
        new Thread(new Runnable(){
            public void run(){
                if(player!= null) player.close(); // close the previous player object, if any, when recording something new
                // resuming from a pause on recording
                if(recPaused){
                    rc.startRecord();
                    recPaused=false;                    
                }
                else {
                    try {
                    recordedSoundArray = null; // reset
                    recordingStopped=false; // reset flag on new recording    
                    recorder = Manager.createPlayer("capture://audio?encoding=amr");//("capture://audio?encoding=amr),("capture://audio?encoding=pcm"),("capture://devmic0?encoding=pcm")
                    recorder.addPlayerListener(myListener);
                    recorder.realize();                   
                    // get the RecordControl over this Player                    
                    rc = (RecordControl)recorder.getControl("RecordControl");
                    // create an OutputStream which the RecordControl will use
                    // to write the recorded data.                    
                    output = new ByteArrayOutputStream();
                    rc.setRecordSizeLimit(MAX_LIMIT); // recording on a maximum limit of bytes, rather than sleeping the thread                    
                    rc.setRecordStream(output);          
                    // start the recording
                    rc.startRecord();
                    recorder.start();
                    } catch (IOException ioe) {
                    	//Display alert if an error occurs.......
            			Alert errorAlert = new Alert("","Error: record IOException in record method (PlayerRecorder) " + ioe.getMessage(),null,AlertType.ERROR);
            			errorAlert.setTimeout(Alert.FOREVER);
            			myView.comm.midlet.display.setCurrent(errorAlert);
           
                    } catch (MediaException me) {
                    	//Display alert if an error occurs.......
            			Alert errorAlert = new Alert("","Error: record MediaException in record method (PlayerRecorder) " + me.getMessage(),null,AlertType.ERROR);
            			errorAlert.setTimeout(Alert.FOREVER);
            			myView.comm.midlet.display.setCurrent(errorAlert);
                    } catch(OutOfMemoryError om){
                    	//Display alert if an error occurs.......
               			Alert errorAlert = new Alert("","Error: Out of memory exception in record method (PlayerRecorder) " + om.getMessage(),null,AlertType.ERROR);
               			errorAlert.setTimeout(Alert.FOREVER);               			
               			myView.comm.midlet.display.setCurrent(errorAlert);
                    } 
                }
            }
        }).start();
       
    }  
    
    public void play(){
    
        if (player == null || player.getState()==player.CLOSED){
            try {
                ByteArrayInputStream recordedInputStream = new ByteArrayInputStream(recordedSoundArray);
                //player= Manager.createPlayer(recordedInputStream,"audio/x-wav");// (recordedInputStream,"audio/basic");
                player= Manager.createPlayer(recordedInputStream,"audio/amr");// (recordedInputStream,"audio/amr");
                player.addPlayerListener(this);
                player.realize();
                player.prefetch();               
                player.start();
            }  catch (IOException ioe) {
                System.out.println("IO exception in play.... " + ioe.getMessage());
                //Display alert if an error occurs.......
       			Alert errorAlert = new Alert("","Error: IO exception in play method (PlayerRecorder) " + ioe.getMessage(),null,AlertType.ERROR);
       			errorAlert.setTimeout(Alert.FOREVER);       			
       			myView.comm.midlet.display.setCurrent(errorAlert);
            } catch (MediaException me) {
            	//Display alert if an error occurs.......
       			Alert errorAlert = new Alert("","Error: Media exception in play method (PlayerRecorder)" + me.getMessage(),null,AlertType.ERROR);
       			errorAlert.setTimeout(Alert.FOREVER);       			
       			myView.comm.midlet.display.setCurrent(errorAlert);
            }
        }
        else {
            try{
                //player was paused and is played again
                //start the player from current media time
                player.start();
            }catch(MediaException me){               
            	//Display alert if an error occurs.......
       			Alert errorAlert = new Alert("","Error: Media exception in play method (PlayerRecorder) " + me.getMessage(),null,AlertType.ERROR);
       			errorAlert.setTimeout(Alert.FOREVER);      			
       			myView.comm.midlet.display.setCurrent(errorAlert);
            }
        }       
     }  
    
    public void stop(int m){
            if(m==2){
            	//stop called on record....
            recordingStopped = true;
            try {            	
                rc.commit();
                // save the recordedData in a byte array    
                recordedSoundArray = output.toByteArray();
                output.close();
                // close the player
                recorder.close();           
            } catch (OutOfMemoryError ome){                               
            	//Display alert if an error occurs.......
       			Alert errorAlert = new Alert("","Error: out of memory in stop method (PlayerRecorder) " + ome.getMessage(),null,AlertType.ERROR);
       			errorAlert.setTimeout(Alert.FOREVER);      			
       			myView.comm.midlet.display.setCurrent(errorAlert);
                
            } catch (IOException ex) {
            	//Display alert if an error occurs.......
       			Alert errorAlert = new Alert("","Error: IO exception in stop method (PlayerRecorder) " + ex.getMessage(),null,AlertType.ERROR);
       			errorAlert.setTimeout(Alert.FOREVER);       			
       			myView.comm.midlet.display.setCurrent(errorAlert);
       		}                        
        }
        
        else if(m==3){
        	//stop called on play
        	myView.messageItem.setText("stop on play ");
            if(player!=null && player.getState()==player.STARTED){
                    player.close();                        
            }
        }        
    }
    
    public void pause(int m){
        if(m==4){
            // pause called on record....
            if(recorder!=null && recorder.getState()==recorder.STARTED){              
            		//pause the recorder. Note that recorder does not rewind to beginning when stop is called
                    recPaused=true; // pause flag
                    rc.stopRecord();
           }                   
        }
        else if(m==5){
            // pause called on play   
            if(player!=null && player.getState()==player.STARTED){
                try {
                	//stop the player. Note that player does not rewind to beginning when pause is called
                    player.stop();
                }catch(MediaException me){                    
                	//Display alert if an error occurs.......
           			Alert errorAlert = new Alert("","Error: Media exception in pause method (PlayerRecorder) " + me.getMessage(),null,AlertType.ERROR);
           			errorAlert.setTimeout(Alert.FOREVER);          			
           			myView.comm.midlet.display.setCurrent(errorAlert);
                }                                
            }       
        }      
    }

    public void playerUpdate(Player player, String event, Object eventData) {
            // player listener, fires events on completion of media in play mode, as well as record mode.
            if(player==player && event==END_OF_MEDIA){
                player.close();
                myView.stopped(); // reset buttons in UI after stopped playing file   
            }

            if(player==recorder && event==RECORD_STOPPED && recordingStopped == false && recPaused == false){
                stop(2); // stop recording
                myView.stopped(); // reset buttons in UI after stopped recording file            
            }
        }      
}