package peer2me.framework;

import peer2me.message.Message;
import peer2me.node.Node;

/**
 * This interface must be implemented by the application using
 * the Peer2Me framework, and defines required methods
 * @author Tommy Bjoernsgaard
 *
 */
public interface FrameworkSubscriber
{
	/**
	 * This method is called whenever a new {@link peer2me.node.Node} is discovered
	 * @param node the node which is discovered
	 */
	public void nodeDiscovered(Node node);
	
	/**
	 * This is called whenever a {@link peer2me.node.Node} is lost or abscent 
	 * @param node the node that is lost or abscent
	 */
	public void nodeLost(Node node);
	
	/**
	 * This method is called whenever a {@link peer2me.message.Message} is received
	 * @param message the message that is received
	 */
	public void messageReceived(Message message);
	
	/**
	 * This method is called for every part of a whole {@link peer2me.message.Message}
	 * that is received. Is well suited for display progressbars in the GUI etc.
	 * @param messageID the id of the message the part belongs to
	 * @param part the current part received
	 * @param total the total of parts to be received
	 */
	public void messagePartReceived(String messageID, int part, int total);
	
	/**
	 * This method is called whenever a search for devices and services is finished.
	 *
	 */
	public void searchCompleted();
}
