package peer2me.log;

/**
 * Describing an entry in the log as a
 * LogElement holding {@link peer2me.log.LogElementType} and a
 * {@link peer2me.log.LogElementDate} along with a textual 
 * description. 
 * @author Tommy Bjoernsgaard
 *
 */
public class LogElement
{
	private LogElementType logEntryType;
	private LogElementDate logEntryDate;
	private String description;
	
	/**
	 * Creates a new LogElement wiht a type and a 
	 * text, and adds the current date/time in form of a
	 * LogEntryDate object. 
	 * This constructor is not visible, but accessed
	 * through the Log-class.
	 * @param type The LogEntryType
	 * @param text The description of the log-entry.
	 */
	protected LogElement(LogElementType type, String text, boolean showDate, boolean showTime)
	{
		this.logEntryType = type;
		this.logEntryDate = new LogElementDate(showDate,showTime);
		this.description = text;
	}

	/**
	 * Gets the date/time of the log-entry
	 * @return the date as a LogElementDate object
	 */
	public LogElementDate getDate()
	{
		return logEntryDate;
	}

	/**
	 * Gets the type of log-entry
	 * @return An int describing the LogElementType
	 */
	public LogElementType getType()
	{
		return logEntryType;
	}

	/**
	 * Gets the description of the log-entry
	 * @return The string describing the log-entry
	 */
	public String getText()
	{
		return description;
	}

	/**
	 * Gives a better textual description.
	 */
	public String toString()
	{
		return logEntryDate.toString()+" - "+logEntryType+" - "+description;
	}	
}