package peer2me.log;

import java.util.Date;

import peer2me.util.TextUtil;

/**
 * A simple class for storing the date/time in
 * which a logentry is created.
 * Mainly used to format the date in a more
 * presentable manner.
 * @author Tommy Bjoernsgaard
 *
 */
public class LogElementDate
{
	private Date date;
	private String[] dateParts;
	private boolean showDate;
	private boolean showTime;

	/**
	 * Creating a new LogElementdate with
	 * the date/time sat to the current time 
	 */
	protected LogElementDate(boolean showDate, boolean showTime)
	{
		date = new Date();
		dateParts = TextUtil.split(date.toString(),' ');
		this.showDate = showDate;
		this.showTime = showTime;
	}

	/**
	 * Gets the Date-object
	 * @return the actual Date-object
	 */
	public Date getDate()
	{
		return date;
	}
	
	/**
	 * Gets a presentable string of the date/time.
	 * An example of the return value: 02.Apr 20:50:39
	 * Will return the same toString();
	 * @return The formatted string
	 */
	public String getDateString()
	{
		return this.toString();
	}
	
	/**
	 * Overrides the default toString() returning 
	 * a formatted string of the Date-object 
	 */
	public String toString()
	{
		String returnString = "";
		if(showDate)
			returnString += dateParts[2]+"."+dateParts[1];
		if(showTime)
			returnString += " "+dateParts[3];
		
		return returnString;
	}
	
	
}
