package peer2me.message;

/**
 * A class that contains information about a received file. 
 * @author Kim Saxlund
 *
 */
public class FileInfo
{
	private String fileName;
	private String fullPathToFile;
	private long fileSize;
	
	/**
	 * Constructor which creates the FileInfo object
	 * @param fileName The name of the file with extension
	 * @param fullPathToFile The full path to the file including name of file
	 * @param fileSize The size of the file in number of bytes
	 */
	public FileInfo(String fileName, String fullPathToFile, long fileSize)
	{
		this.fileName = fileName;
		this.fullPathToFile = fullPathToFile;
		this.fileSize = fileSize;
	}

	/**
	 * Returns the name of the file
	 * @return The filename
	 */
	public String getFileName()
	{
		return fileName;
	}

	/**
	 * Returns the size of the file
	 * @return The size is given in bytes
	 */
	public long getFileSize()
	{
		return fileSize;
	}

	/**
	 * Returns the full path of the file
	 * @return The full path of the file. For instance: <code>file:///SDCard/images/animal.jpg</code>
	 */
	public String getFullPathToFile()
	{
		return fullPathToFile;
	}
}
