package peer2me.message;

import java.io.DataInputStream;
import java.util.Stack;

import peer2me.log.Log;
import peer2me.log.LogElementType;

/**
 * When a node receives a stream of bytes, this class deserializes the stream and creates an
 * object of it. This class calls the implemented deserialize() method from the Serializable
 * interface. The object that is created must be casted to the correct class. This task must be
 * solved by the application developer.
 * @author Kim Saxlund
 * @see peer2me.message.Serializable
 *
 */
public class ObjectInputStream
{
	private Object o = null;

	/**
	 * Constructor that starts deserializing the stream at once
	 * @param in The DataInputStream that needs to be deserialized
	 */
	public ObjectInputStream(DataInputStream in)
	{
		try
		{
			if(0x0 != in.readByte())
			{
				o = Class.forName(in.readUTF()).newInstance();
				Stack stack = new Stack();
				try
				{
					((Serializable)o).deSerialize(in, stack);
					while( !(stack.empty()) )
					{
						Object local = stack.pop();
						((Serializable)local).deSerialize(in, stack );
					}
				}
				catch(Exception e)
				{
					Log.getInstance().addElement(LogElementType.ERROR,"Error deserializing object: " + e.getMessage());
					e.printStackTrace();
				}
			}
		}
		catch(Exception e)
		{
			Log.getInstance().addElement(LogElementType.ERROR,"Error instansiating object " + e.getMessage());
			e.printStackTrace(); 
		}
	}
	
	/**
	 * Returns the object that was deserialized
	 * @return The deserialized object. Should be casted to the correct class when returned.
	 */
	public Object getObject()
	{
		return o;
	}
}