package peer2me.message;
import java.util.Stack;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * When a serialized object is added to a message, this class serializes it into a bytestream so
 * that it can be sent over the network. This class calls the implemented serialize() method
 * from the Serializable interface.
 * @author saxlund
 * @see peer2me.message.Serializable
 *
 */
public class ObjectOutputStream
{
	private DataOutputStream out;
	private Stack stack = null;
	
	/**
	 * Constructor that starts serializing the object at once
	 * @param o The object that will be serialized into a stream.
	 * @param ot The stream that the object will be serialized to
	 */
	public ObjectOutputStream (Object o, DataOutputStream ot)
	{
		this.out = ot;
		stack = new Stack();
		
		int tmp = 127;
		try
		{
			if(o != null)
			{
				out.writeByte(tmp);
				out.writeUTF(o.getClass().getName());
				((Serializable)o).serialize(out,stack);
				
				while( !(stack.empty()) )
				{
					Object aux = stack.pop();
					((Serializable)aux).serialize(out,stack);
				}
			}
			else
			{
				tmp = 0;
				out.writeByte(tmp);
			}
		}
		catch(IOException e)
		{
			e.printStackTrace();
		}
	}
}