package peer2me.message;
import java.io.IOException;
import java.io.DataOutputStream;
import java.io.DataInputStream;
import java.util.Stack;

/**
 * This interface must be implemented by all Java objects that are going to be sent over the network as
 * serializable objects.
 * 
 * Classes that implements this interface MUST have a public empty constructor that takes no arguments. 
 * It may also have additional constructors. Also, the class that implements this interface MUST, in the 
 * <code>deserialize()</code> method refer to it's own classname with full packagename. For instance, the class
 * <code>SendableNodeInfo</code>, refers to itself as: <code>peer2me.message.SendableNodeInfo</code>
 * @author saxlund
 *
 */
public interface Serializable 
{
	public void serialize(DataOutputStream dos,Stack stack)	throws IOException;
	
	public void deSerialize(DataInputStream dis,Stack stack) throws IOException, ClassNotFoundException,
	IllegalAccessException, InstantiationException;
}