package peer2me.network;

/**
 * The is an abstract class used to represent a node
 * with network specific information.
 * Should be extended
 * by the class representing the networktechnology.
 * I.e. {@link peer2me.network.bluetooth.BluetoothNode} extends this class.
 * @author Tommy Bjoernsgaard
 *
 */
public abstract class NetworkNode
{	
	protected String name;
	protected String address;
	protected Object object;
	protected String connectionURL = "";
	
	/**
	 * Gets the name of the networknode
	 * @return the name
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 * Gets the address of the networknode
	 * @return the address
	 */
	public String getAddress()
	{
		return address;
	}
	
	/**
	 * Gets the connection url of the networknode
	 * @return the connection url
	 */
	public String getConnectionURL()
	{
		return connectionURL; 
	}

	/**
	 * Gets the universal object for the networknode
	 * @return the object
	 */
	public Object getObject()
	{
		return object;
	}
	
	/**
	 * The class that inherits this class should override the default
	 * <code>toString()</code>, making the output more friendly
	 */
	public abstract String toString();
}
