package peer2me.network.bluetooth;

import javax.microedition.io.Connection;
import javax.obex.HeaderSet;
import javax.obex.ResponseCodes;
import javax.obex.ServerRequestHandler;

/**
 * This class is responsible for handling incomming ping-connections. It will accept all incoming
 * connections, but a connection will be closed at the remote end as soon as it has been established.
 * The whole purpose is just to check to see if the local node is alive.
 * This class extends <a href="http://www.j2medev.com/api/btapi/javax/obex/ServerRequestHandler.html">javax.obex.ServerRequestHandler</a>
 * @author Kim Saxlund
 *
 */
public class BluetoothPingConnectionHandler extends ServerRequestHandler
{

	private Connection connection;
	private Thread parentThread;
	private boolean finished = false;
	
	/**
	 * Constructor. Sets local references to the paramteres given.
	 * @param connection The connection that is associated with this handler
	 * @param parentThread The parent thread
	 */
	public BluetoothPingConnectionHandler(Connection connection, Thread parentThread)
	{
		this.connection = connection;
		this.parentThread = parentThread;
	}
	
	/**
	 * Inherited method from javax.obex.ServerRequestHandler. 
	 * Is invoked when a remote device tries to
	 * establish a connection. This implementation accepts all connections.
	 * @param reply A HeaderSet that can be used to send a reply
	 * @param request The HeaderSet that is sent from the remote device
	 */
	public int onConnect(HeaderSet request, HeaderSet reply) 
	{
		finished = true;
		synchronized (parentThread)
		{
			parentThread.notify();
		}
		return ResponseCodes.OBEX_HTTP_OK;
	}

	/**
	 * Sets a reference to the connection that is assosiated with this handler. This method is
	 * called by {@link BluetoothPingListener}.
	 * @param connection The connection
	 */
	public void setConnection(Connection connection)
	{
		this.connection = connection;
		this.connection.toString();
	}

	/**
	 * If this class has successfully established an incoming connection, this method will return true. 
	 * @return True if a connection was established, false if the connection has not been established yet
	 */
	public boolean isFinished()
	{
		return finished;
	}

}
