package peer2me.network.bluetooth;

import java.io.IOException;

import javax.obex.HeaderSet;

/**
 * This class contains user defined headers. The headers are used to create headersets that are specialized
 * for the Peer2Me framework. The headers are used in OBEX connections and data transfers.
 * @author Kim Saxlund
 *
 */
public class Peer2MeHeaderSet implements HeaderSet
{

	/*
	 * Available user defined HeaderSet ranges:
	 * Header Identifier	Decimal Range	OBEX Type  					Java Type
	 * 0x30 to 0x3F			48 to 63		Unicode String 				java.lang.String
	 * 0x70 to 0x7F			112 to 127		byte sequence 				byte[]
	 * 0xB0 to 0xBF			176 to 191		1 byte 						java.lang.Byte
	 * 0xF0 to 0xFF			240 to 255		4 byte unsigned integer 	java.lang.Long
	 * 
	 * */
	/**
	 * The network address of the sender of the message should be associated with this header
	 */
	public static final int SENDER_ADDRESS = 48;
	/**
	 * The name of the sender of the message should be associated with this header
	 */
	public static final int SENDER_NAME = 49;
	/**
	 * The length of the datastream that is sent directly after the headers are sent.
	 */
	public static final int LENGTH = 50;
	/**
	 * The ID of the message. If a message is sent in several chunks, this ID must be used to identify which
	 * message the chunk belongs to.
	 */
	public static final int MESSAGE_ID = 51;
	/**
	 * If a message is sent in several chunks, each chunk must know which number it is. 
	 */
	public static final int MESSAGE_NUMBER = 52;
	/**
	 * The total number of chunks that this message consists of.
	 */
	public static final int TOTAL_NUMBER_OF_MESSAGES = 53;
	/**
	 * If the datastream that is sent directly after the headers is the contents of a file, this header
	 * can be used to tell if this chunks contains the last data in the file.
	 */
	public static final int END_OF_FILE = 54;
	/**
	 * The ID of a messagepart. Files are usually be sent in several chunks. Since files are associated with
	 * a messagepart, this header is necessary to identify which messagepart the file belongs to.
	 */
	public static final int MESSAGE_PART_ID = 55;
	/**
	 * The name of the file.
	 */
	public static final int FILE_NAME = 56;
	/**
	 * The total size of the file.
	 */
	public static final int FILE_SIZE = 57;
	/**
	 * Can be used to send information about all the recipients in a message. Is currently not in use.
	 */
	public static final int RECIPIENTS = 58;
	
	/**
	 * Required  method from interface.
	 * Not implemented.
	 */
	public void createAuthenticationChallenge(String realm, boolean userID, boolean access) 
	{		
	}

	/**
	 * Required  method from interface.
	 * Not implemented.
	 */
	public Object getHeader(int arg0) throws IOException 
	{
		return null;
	}

	/**
	 * Required  method from interface.
	 * Not implemented.
	 */
	public int[] getHeaderList() throws IOException 
	{
		return null;
	}

	/**
	 * Required  method from interface.
	 * Not implemented.
	 */
	public int getResponseCode() throws IOException 
	{
		return 0;
	}

	/**
	 * Required  method from interface.
	 * Not implemented.
	 */
	public void setHeader(int arg0, Object arg1) 
	{
	}

}
