package peer2me.network.bluetooth;

import peer2me.node.Node;

/**
 * This class processes the pingqueue that is located in {@link peer2me.network.bluetooth.Bluetooth}.
 * This class constantly watches the queue, and when a pingmessage is added to the queue, this class 
 * tries to establish a connection to the node in the pingmessage. The connection is immediately closed 
 * if it was created.
 * @author Kim Saxlund
 *
 */
public class PingQueueProcessor implements Runnable
{
	Bluetooth bluetooth;
	boolean processQue = true;
	private Thread thisThread;
	
	/**
	 * Constructor. Starts this thread.
	 * @param bluetooth Reference to the Bluetooth class
	 */
	public PingQueueProcessor(Bluetooth bluetooth)
	{
		this.bluetooth = bluetooth;
		thisThread = new Thread(this);
		thisThread.start();
	}
	
	/**
	 * Runs as long as the private boolean <code>processQueue</code> is true. 
	 * Checks the pingqueue at regular intervals. When a ping is added to the queue, this
	 * method creates an instance of BluetoothObjectPush and tries to establish a connection to the 
	 * assosiated node. 
	 */
	public void run()
	{
		while(processQue)
		{
			while(bluetooth.getPingQue().isEmpty())
			{
				try
				{
					Thread.sleep(500);
				} 
				catch (InterruptedException e)
				{}
			}
			Thread innerThread = new Thread(new Runnable() 
			{
				public void run() 
				{
					Node node = bluetooth.getPingQue().getFirstNode();
					BluetoothNode bluetoothNode = (BluetoothNode)node.getNetworkNode();
					node.incrementPing();
					BluetoothObjectPush bp = new BluetoothObjectPush();
					int counter = 0;
					while(counter < 3)
					{	
						//Node alive
						if(bp.connect(bluetoothNode.getPingConnectionURL()))
						{
							bp.closeConnection();
							node.incrementEcho();
							break;
						}
						try
						{
							Thread.sleep(1000);
						} 
						catch (InterruptedException e)
						{}
						counter++;
					}
					bluetooth.checkPingResponse(node);
					synchronized (thisThread) 
					{
						thisThread.notify();
					}
				}
			});
			innerThread.start();
			synchronized (thisThread) 
			{
				try 
				{
					thisThread.wait();
				} 
				catch (InterruptedException e)
				{}
			}
		}
	}
	
	/**
	 * If the queue is being checked at regular intervals, this method returns true
	 * @return True if queue is being checked, false otherwise
	 */
	public boolean isProcessQue()
	{
		return processQue;
	}

	/**
	 * Can be used to stop this thread. Use 'false' as parameter, and this thread will stop
	 * checking the queue, and finish
	 * @param processQue Use false to stop checking the queue
	 */
	public void setProcessQue(boolean processQue)
	{
		this.processQue = processQue;
	}
}
