package peer2me.service;

import peer2me.exception.HexConversionException;

/**
 * This class contains the tool for converting a simple string
 * into a 32-character hexstring used as a serviceID. Enables the 
 * user to type a normal ASCII-string as ServiceID.
 * @author Tommy Bjoernsgaard
 *
 */
public class HexBuilder
{
	/**
	 * Complete list of hex-characters
	 */
	private static final char[] hex = {'0', '1', '2', '3', '4', '5', '6', '7','8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};

    /**
     * A static method taking a normal ASCII-string transforming it
     * into a correspondent string in hex codes.
     * This method will output a 32 character string regardless of
     * the length of the input-string.
     * @param serviceID The string in ASCII containing the desired serviceID
     * @return The string in HEX-characters containing the serviceID
     */
	public static String getHexString(String serviceID) throws HexConversionException
    {
    	try
		{
			byte[] bytes = serviceID.getBytes();
			StringBuffer stringBuffer = new StringBuffer();

			//Two hex characters will correspond to each character
			for (int i=0; i < bytes.length; i++) 
			{
				stringBuffer.append(hex[(bytes[i] >> 4) & 0xf]);
				stringBuffer.append(hex[bytes[i] & 0xf]);
			}
			
			String returnString = new String(stringBuffer);
			int length = 0;returnString.length();
			
			//Ensuring the final string is the desired length
			while(length < 32)
			{
				length = returnString.length();
				returnString += returnString;
			}		
			return returnString.substring(0,32);
		} 
    	catch (Exception e)
		{
			throw new HexConversionException();
		}
    }
}
