package peer2me.service;

import peer2me.exception.HexConversionException;
import peer2me.log.Log;
import peer2me.log.LogElementType;

/**
 * A class to store the ServiceID in.
 * Stored both in ASCII and HEX format.
 * @author Tommy Bjoernsgaard
 *
 */
public class Service 
{
	private String hexServiceID;
	private String hexPingServiceID;
	private String asciiServiceID;
	private String asciiPingServiceID = "";
	
	/**
	 * Creates a new ServiceID and a PingServiceID.
	 * Uses {@link peer2me.service.HexBuilder#getHexString(String)} to convert the 
	 * serviceID in ASCII-format to HEX-format.
	 * If this fails, default serviceIDs is sat.
	 * @param serviceID the serviceID in ASCII
	 */
	public Service(String serviceID)
	{
		asciiServiceID = serviceID;
		asciiPingServiceID = serviceID + "ping";
		try
		{
			this.hexServiceID = HexBuilder.getHexString(serviceID);
			this.hexPingServiceID = HexBuilder.getHexString(serviceID + "ping");
		} 
		catch (HexConversionException e)
		{
			Log.getInstance().addElement(LogElementType.WARNING,"Could not create ServiceID. Default ServiceID sat.");
			this.hexServiceID = "afbe2323800002373646fff3273eaaac";
			this.hexPingServiceID = "afbe2323800002373646fff3273eping";
		}
	}
	
	/**
	 * Gets the serviceID in ASCII
	 * @return the string containing the serviceID
	 */
	public String getASCIIServiceID()
	{
		return asciiServiceID;
	}
	
	/**
	 * Gets the serviceID in HEX
	 * @return the string containing the hexServiceID
	 */
	public String getHexServiceID()
	{
		return hexServiceID;
	}

	/**
	 * Gets the pingServiceID in HEX
	 * @return the string containing the hexPingServiceID
	 */
	public String getHexPingServiceID()
	{
		return hexPingServiceID;
	}
	/**
	 * Gets the asciiServiceID in ASCII
	 * @return the string containing the asciiPingServiceID
	 */
	public String getAsciiPingServiceID()
	{
		return asciiPingServiceID;
	}
}
