package peer2me.util;

import java.util.Enumeration;

import javax.microedition.io.file.FileSystemRegistry;

import peer2me.log.Log;
import peer2me.log.LogElementType;


/**
 * This class is used to store information about the mobile 
 * phone's receive-folder. This is done by getting the phone's
 * root directories using {@link #getRootDirectories()}, and adding the given <code>prefic</code>
 * @author Kim Saxlund
 *
 */
public class FileHandler
{
	//The path to the current directory
	private static final String prefix = "file:///";
	private static final String defaultfolder = "tempp2me/";
	private String receivedFilesFolder = "";
	
	private static FileHandler singleton = null;
	
	/**
	 * Default constructor. Sat private due to singelton.
	 */
	private FileHandler()
	{		
	}
	
	/**
	 * Gets a reference FileHandler using singelton
	 * @return a reference to FileHandler
	 */
	public static synchronized FileHandler getInstance()
	{
		if(singleton == null)
		{
			singleton = new FileHandler();
		}
		return singleton;
	}
	

	/**
	 * Returns an enumeration list of the contents of the root directory
	 * @return An enumeration list with the root directories
	 */
	private Enumeration getRootDirectories()
	{	
		return FileSystemRegistry.listRoots();	
	}
	
	/**
	 * Gets the path to the folder where received files are stored
	 * @return a String containing the path to where the received files are stored. 
	 */
	public String getReceivedFilesFolder()
	{
		if(receivedFilesFolder.equals(""))
			setDefaultReceivedFilesFolder();
		return receivedFilesFolder;
	}

	/**
	 * Sets a default folder where received files are stored.
	 * The directorypath is sat to the first root directory and the
	 * folder sat in <code>defaultfolder</code>.
	 *
	 */
	private void setDefaultReceivedFilesFolder()
	{
		Enumeration e = getRootDirectories();
		//Setting default downloaddirectory to the first root-directory it finds and adds a 
		//temp dir to it... Example: file:///Root1/tempp2me
		if(e!=null)
		{
			receivedFilesFolder = prefix + e.nextElement().toString() + defaultfolder;
		}
		Log.getInstance().addElement(LogElementType.INFORMATION,"FileHandler, setting folder: " + receivedFilesFolder);
	}
	
	/**
	 * Sets a default folder where received files are stored
	 * according to the input.
	 * @param receivedFilesFolder the folder where received files are stored.
	 */
	public void setReceivedFilesFolder(String receivedFilesFolder)
	{
		this.receivedFilesFolder = prefix + receivedFilesFolder;
	}
}

